@@ -14,8 +14,6 @@ from pathlib import Path
 import shlex
 import shutil
 
-import requests
-import requests.exceptions
 
 from .hashes import hash_matches, file_hash
 from .utils import (
@@ -86,7 +84,7 @@ def retrieve(
         existing file needs to be updated.
     fname : str or None
         The name that will be used to save the file. Should NOT include the
-        full the path, just the file name (it will be appended to *path*). If
+        full path, just the file name (it will be appended to *path*). If
         None, will create a unique file name using a combination of the last
         part of the URL (assuming it's the file name) and the MD5 hash of the
         URL. For example, ``81whdo2d2e928yd1wi22-data-file.csv``. This ensures
@@ -217,15 +215,17 @@ def retrieve(
         path = os_cache("pooch")
     if fname is None:
         fname = unique_file_name(url)
-    # Create the local data directory if it doesn't already exist and make the
-    # path absolute.
+    # Make the path absolute.
     path = cache_location(path, env=None, version=None)
-    make_local_storage(path)
 
     full_path = path.resolve() / fname
     action, verb = download_action(full_path, known_hash)
 
     if action in ("download", "update"):
+        # We need to write data, so create the local data directory if it
+        # doesn't already exist.
+        make_local_storage(path)
+
         get_logger().info(
             "%s data from '%s' to file '%s'.",
             verb,
@@ -560,9 +560,6 @@ class Pooch:
         """
         self._assert_file_in_registry(fname)
 
-        # Create the local data directory if it doesn't already exist
-        make_local_storage(str(self.abspath))
-
         url = self.get_url(fname)
         full_path = self.abspath / fname
         known_hash = self.registry[fname]
@@ -574,6 +571,10 @@ class Pooch:
             )
 
         if action in ("download", "update"):
+            # We need to write data, so create the local data directory if it
+            # doesn't already exist.
+            make_local_storage(str(self.abspath))
+
             get_logger().info(
                 "%s file '%s' from '%s' to '%s'.",
                 verb,
@@ -789,6 +790,9 @@ def stream_download(url, fname, known_hash, downloader, pooch=None, retry_if_fai
     will retry the download the specified number of times in case the failure
     was due to a network error.
     """
+    # Lazy import requests to speed up import time
+    import requests.exceptions  # pylint: disable=C0415
+
     # Ensure the parent directory exists in case the file is in a subdirectory.
     # Otherwise, move will cause an error.
     if not fname.parent.exists():
