@@ -12,7 +12,6 @@ import sys
 import ftplib
 
 import warnings
-import requests
 
 from .utils import parse_url
 
@@ -192,6 +191,9 @@ class HTTPDownloader:  # pylint: disable=too-few-public-methods
             is available on the server. Otherwise, returns ``None``.
 
         """
+        # Lazy import requests to speed up import time
+        import requests  # pylint: disable=C0415
+
         if check_only:
             response = requests.head(url, allow_redirects=True)
             available = bool(response.status_code == 200)
@@ -514,7 +516,7 @@ class DOIDownloader:  # pylint: disable=too-few-public-methods
 
     * `figshare <https://www.figshare.com>`__
     * `Zenodo <https://www.zenodo.org>`__
-    * `DataVerse <https://dataverse.org/>`__ instances
+    * `Dataverse <https://dataverse.org/>`__ instances
 
     .. attention::
 
@@ -626,6 +628,9 @@ def doi_to_url(doi):
         The URL of the archive in the data repository.
 
     """
+    # Lazy import requests to speed up import time
+    import requests  # pylint: disable=C0415
+
     # Use doi.org to resolve the DOI to the repository website.
     response = requests.get(f"https://doi.org/{doi}")
     url = response.url
@@ -743,10 +748,13 @@ class DataRepository:  # pylint: disable=too-few-public-methods, missing-class-d
 
 
 class ZenodoRepository(DataRepository):  # pylint: disable=missing-class-docstring
+    base_api_url = "https://zenodo.org/api/records"
+
     def __init__(self, doi, archive_url):
         self.archive_url = archive_url
         self.doi = doi
         self._api_response = None
+        self._api_version = None
 
     @classmethod
     def initialize(cls, doi, archive_url):
@@ -777,15 +785,49 @@ class ZenodoRepository(DataRepository):  # pylint: disable=missing-class-docstri
     @property
     def api_response(self):
         """Cached API response from Zenodo"""
-
         if self._api_response is None:
+            # Lazy import requests to speed up import time
+            import requests  # pylint: disable=C0415
+
             article_id = self.archive_url.split("/")[-1]
             self._api_response = requests.get(
-                f"https://zenodo.org/api/records/{article_id}"
+                f"{self.base_api_url}/{article_id}"
             ).json()
 
         return self._api_response
 
+    @property
+    def api_version(self):
+        """
+        Version of the Zenodo API we are interacting with
+
+        The versions can either be :
+
+        - ``"legacy"``: corresponds to the Zenodo API that was supported until
+          2023-10-12 (before the migration to InvenioRDM).
+        - ``"new"``: corresponds to the new API that went online on 2023-10-13
+          after the migration to InvenioRDM.
+
+        The ``"new"`` API breaks backward compatibility with the ``"legacy"``
+        one and could probably be replaced by an updated version that restores
+        the behaviour of the ``"legacy"`` one.
+
+        Returns
+        -------
+        str
+        """
+        if self._api_version is None:
+            if all(["key" in file for file in self.api_response["files"]]):
+                self._api_version = "legacy"
+            elif all(["filename" in file for file in self.api_response["files"]]):
+                self._api_version = "new"
+            else:
+                raise ValueError(
+                    "Couldn't determine the version of the Zenodo API for "
+                    f"{self.archive_url} (doi:{self.doi})."
+                )
+        return self._api_version
+
     def download_url(self, file_name):
         """
         Use the repository API to get the download URL for a file given
@@ -800,14 +842,35 @@ class ZenodoRepository(DataRepository):  # pylint: disable=missing-class-docstri
         -------
         download_url : str
             The HTTP URL that can be used to download the file.
-        """
 
-        files = {item["key"]: item for item in self.api_response["files"]}
+        Notes
+        -----
+        After Zenodo migrated to InvenioRDM on Oct 2023, their API changed. The
+        link to the desired files that appears in the API response leads to 404
+        errors (by 2023-10-17). The files are available in the following url:
+        ``https://zenodo.org/records/{article_id}/files/{file_name}?download=1``.
+
+        This method supports both the legacy and the new API.
+        """
+        # Create list of files in the repository
+        if self.api_version == "legacy":
+            files = {item["key"]: item for item in self.api_response["files"]}
+        else:
+            files = [item["filename"] for item in self.api_response["files"]]
+        # Check if file exists in the repository
         if file_name not in files:
             raise ValueError(
-                f"File '{file_name}' not found in data archive {self.archive_url} (doi:{self.doi})."
+                f"File '{file_name}' not found in data archive "
+                f"{self.archive_url} (doi:{self.doi})."
+            )
+        # Build download url
+        if self.api_version == "legacy":
+            download_url = files[file_name]["links"]["self"]
+        else:
+            article_id = self.api_response["id"]
+            download_url = (
+                f"https://zenodo.org/records/{article_id}/files/{file_name}?download=1"
             )
-        download_url = files[file_name]["links"]["self"]
         return download_url
 
     def populate_registry(self, pooch):
@@ -818,10 +881,22 @@ class ZenodoRepository(DataRepository):  # pylint: disable=missing-class-docstri
         ----------
         pooch : Pooch
             The pooch instance that the registry will be added to.
-        """
 
+        Notes
+        -----
+        After Zenodo migrated to InvenioRDM on Oct 2023, their API changed. The
+        checksums for each file listed in the API reference is now an md5 sum.
+
+        This method supports both the legacy and the new API.
+        """
         for filedata in self.api_response["files"]:
-            pooch.registry[filedata["key"]] = filedata["checksum"]
+            checksum = filedata["checksum"]
+            if self.api_version == "legacy":
+                key = "key"
+            else:
+                key = "filename"
+                checksum = f"md5:{checksum}"
+            pooch.registry[filedata[key]] = checksum
 
 
 class FigshareRepository(DataRepository):  # pylint: disable=missing-class-docstring
@@ -875,8 +950,10 @@ class FigshareRepository(DataRepository):  # pylint: disable=missing-class-docst
     @property
     def api_response(self):
         """Cached API response from Figshare"""
-
         if self._api_response is None:
+            # Lazy import requests to speed up import time
+            import requests  # pylint: disable=C0415
+
             # Use the figshare API to find the article ID from the DOI
             article = requests.get(
                 f"https://api.figshare.com/v2/articles?doi={self.doi}"
@@ -927,7 +1004,6 @@ class FigshareRepository(DataRepository):  # pylint: disable=missing-class-docst
         download_url : str
             The HTTP URL that can be used to download the file.
         """
-
         files = {item["name"]: item for item in self.api_response}
         if file_name not in files:
             raise ValueError(
@@ -974,7 +1050,6 @@ class DataverseRepository(DataRepository):  # pylint: disable=missing-class-docs
         archive_url : str
             The resolved URL for the DOI
         """
-
         # Access the DOI as if this was a DataVerse instance
         response = cls._get_api_response(doi, archive_url)
 
@@ -995,6 +1070,9 @@ class DataverseRepository(DataRepository):  # pylint: disable=missing-class-docs
         This has been separated into a separate ``classmethod``, as it can be
         used prior and after the initialization.
         """
+        # Lazy import requests to speed up import time
+        import requests  # pylint: disable=C0415
+
         parsed = parse_url(archive_url)
         response = requests.get(
             f"{parsed['protocol']}://{parsed['netloc']}/api/datasets/"
@@ -1034,7 +1112,6 @@ class DataverseRepository(DataRepository):  # pylint: disable=missing-class-docs
         download_url : str
             The HTTP URL that can be used to download the file.
         """
-
         parsed = parse_url(self.archive_url)
 
         # Iterate over the given files until we find one of the requested name
